@@ -1,7 +1,6 @@
 require 'rvg/rvg'
-include Magick
 
-rvg = RVG.new(400, 120) do |canvas|
+rvg = Magick::RVG.new(400, 120) do |canvas|
     canvas.desc = 'Example Skew - Show effects of skewX and skewY'
     canvas.background_fill = 'white'
 
@@ -19,7 +18,7 @@ rvg = RVG.new(400, 120) do |canvas|
                 grp3.line(0, 0, 50, 0)
                 grp3.line(0, 0, 0, 50)
             end
-            grp.text(0, 0, 'ABC (skewX)').styles(:font_size=>20, :fill=>'blue', :font_family=>'Verdana')
+            grp.text(0, 0, 'ABC (skewX)').styles(:font_size=>20, :fill=>'blue', :font_family=>'Verdana', :font_weight=>'normal', :font_style=>'normal')
         end
     end
 
@@ -31,7 +30,7 @@ rvg = RVG.new(400, 120) do |canvas|
                 grp3.line(0, 0, 50, 0)
                 grp3.line(0, 0, 0, 50)
             end
-            grp.text(0, 0, 'ABC (skewY)').styles(:font_size=>20, :fill=>'blue', :font_family=>'Verdana')
+            grp.text(0, 0, 'ABC (skewY)').styles(:font_size=>20, :fill=>'blue', :font_family=>'Verdana', :font_weight=>'normal', :font_style=>'normal')
         end
     end
 end
